@@ -2,6 +2,7 @@
 
 #include <fmt/format.h>
 #include <fstream>
+#include <unordered_map>
 #include "ALabel.hpp"
 #include "util/sleeper_thread.hpp"
 
@@ -14,11 +15,9 @@ class Memory : public ALabel {
   auto update() -> void;
 
  private:
-  static inline const std::string data_dir_ = "/proc/meminfo";
   void                            parseMeminfo();
 
-  unsigned long memtotal_;
-  unsigned long memfree_;
+  std::unordered_map<std::string, unsigned long> meminfo_;
 
   util::SleeperThread thread_;
 };
