@@ -2,8 +2,12 @@
 #include <spdlog/spdlog.h>
 #include <sys/eventfd.h>
 #include <fstream>
+#include <cassert>
+#include <optional>
 #include "util/format.hpp"
-
+#ifdef WANT_RFKILL
+#include "util/rfkill.hpp"
+#endif
 
 namespace {
 
@@ -85,6 +89,9 @@ waybar::modules::Network::Network(const std::string &id, const Json::Value &conf
       cidr_(-1),
       signal_strength_dbm_(0),
       signal_strength_(0),
+#ifdef WANT_RFKILL
+      rfkill_{RFKILL_TYPE_WLAN},
+#endif
       frequency_(0) {
   auto down_octets = read_netstat(BANDWIDTH_CATEGORY, BANDWIDTH_DOWN_TOTAL_KEY);
   auto up_octets = read_netstat(BANDWIDTH_CATEGORY, BANDWIDTH_UP_TOTAL_KEY);
@@ -116,8 +123,6 @@ waybar::modules::Network::Network(const std::string &id, const Json::Value &conf
 
 waybar::modules::Network::~Network() {
   if (ev_fd_ > -1) {
-    eventfd_write(ev_fd_, 1);
-    std::this_thread::sleep_for(std::chrono::milliseconds(150));
     close(ev_fd_);
   }
   if (efd_ > -1) {
@@ -190,11 +195,12 @@ void waybar::modules::Network::createInfoSocket() {
   }
   nl80211_id_ = genl_ctrl_resolve(sock_, "nl80211");
   if (nl80211_id_ < 0) {
-    throw std::runtime_error("Can't resolve nl80211 interface");
+    spdlog::warn("Can't resolve nl80211 interface");
   }
 }
 
 void waybar::modules::Network::worker() {
+  // update via here not working
   thread_timer_ = [this] {
     {
       std::lock_guard<std::mutex> lock(mutex_);
@@ -205,6 +211,20 @@ void waybar::modules::Network::worker() {
     }
     thread_timer_.sleep_for(interval_);
   };
+#ifdef WANT_RFKILL
+  thread_rfkill_ = [this] {
+    rfkill_.waitForEvent();
+    {
+      std::lock_guard<std::mutex> lock(mutex_);
+      if (ifid_ > 0) {
+        getInfo();
+        dp.emit();
+      }
+    }
+  };
+#else
+    spdlog::warn("Waybar has been built without rfkill support.");
+#endif
   thread_ = [this] {
     std::array<struct epoll_event, EPOLL_MAX> events{};
 
@@ -221,7 +241,13 @@ void waybar::modules::Network::worker() {
 }
 
 const std::string waybar::modules::Network::getNetworkState() const {
-  if (ifid_ == -1) return "disconnected";
+  if (ifid_ == -1) {
+#ifdef WANT_RFKILL
+    if (rfkill_.getState())
+      return "disabled";
+#endif
+    return "disconnected";
+  }
   if (ipaddr_.empty()) return "linked";
   if (essid_.empty()) return "ethernet";
   return "wifi";
@@ -278,8 +304,13 @@ auto waybar::modules::Network::update() -> void {
       fmt::arg("bandwidthUpBits", pow_format(bandwidth_up * 8ull / interval_.count(), "b/s")),
       fmt::arg("bandwidthDownOctets", pow_format(bandwidth_down / interval_.count(), "o/s")),
       fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")));
-  if (text != label_.get_label()) {
+  if (text.compare(label_.get_label()) != 0) {
     label_.set_markup(text);
+    if (text.empty()) {
+      event_box_.hide();
+    } else {
+      event_box_.show();
+    }
   }
   if (tooltipEnabled()) {
     if (tooltip_format.empty() && config_["tooltip-format"].isString()) {
@@ -302,13 +333,16 @@ auto waybar::modules::Network::update() -> void {
           fmt::arg("bandwidthUpBits", pow_format(bandwidth_up * 8ull / interval_.count(), "b/s")),
           fmt::arg("bandwidthDownOctets", pow_format(bandwidth_down / interval_.count(), "o/s")),
           fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")));
-      if (label_.get_tooltip_text() != text) {
+      if (label_.get_tooltip_text() != tooltip_text) {
         label_.set_tooltip_text(tooltip_text);
       }
     } else if (label_.get_tooltip_text() != text) {
       label_.set_tooltip_text(text);
     }
   }
+
+  // Call parent update
+  ALabel::update();
 }
 
 // Based on https://gist.github.com/Yawning/c70d804d4b8ae78cc698
@@ -434,7 +468,6 @@ out:
 }
 
 void waybar::modules::Network::getInterfaceAddress() {
-  unsigned int    cidrRaw;
   struct ifaddrs *ifaddr, *ifa;
   cidr_ = 0;
   int success = getifaddrs(&ifaddr);
@@ -446,18 +479,34 @@ void waybar::modules::Network::getInterfaceAddress() {
     if (ifa->ifa_addr != nullptr && ifa->ifa_addr->sa_family == family_ &&
         ifa->ifa_name == ifname_) {
       char ipaddr[INET6_ADDRSTRLEN];
-      ipaddr_ = inet_ntop(family_,
-                          &reinterpret_cast<struct sockaddr_in *>(ifa->ifa_addr)->sin_addr,
-                          ipaddr,
-                          INET6_ADDRSTRLEN);
       char netmask[INET6_ADDRSTRLEN];
-      auto net_addr = reinterpret_cast<struct sockaddr_in *>(ifa->ifa_netmask);
-      netmask_ = inet_ntop(family_, &net_addr->sin_addr, netmask, INET6_ADDRSTRLEN);
-      cidrRaw = net_addr->sin_addr.s_addr;
       unsigned int cidr = 0;
-      while (cidrRaw) {
-        cidr += cidrRaw & 1;
-        cidrRaw >>= 1;
+      if (family_ == AF_INET) {
+        ipaddr_ = inet_ntop(AF_INET,
+                            &reinterpret_cast<struct sockaddr_in *>(ifa->ifa_addr)->sin_addr,
+                            ipaddr,
+                            INET_ADDRSTRLEN);
+        auto net_addr = reinterpret_cast<struct sockaddr_in *>(ifa->ifa_netmask);
+        netmask_ = inet_ntop(AF_INET, &net_addr->sin_addr, netmask, INET_ADDRSTRLEN);
+        unsigned int cidrRaw = net_addr->sin_addr.s_addr;
+        while (cidrRaw) {
+          cidr += cidrRaw & 1;
+          cidrRaw >>= 1;
+        }
+      } else {
+        ipaddr_ = inet_ntop(AF_INET6,
+                            &reinterpret_cast<struct sockaddr_in6 *>(ifa->ifa_addr)->sin6_addr,
+                            ipaddr,
+                            INET6_ADDRSTRLEN);
+        auto net_addr = reinterpret_cast<struct sockaddr_in6 *>(ifa->ifa_netmask);
+        netmask_ = inet_ntop(AF_INET6, &net_addr->sin6_addr, netmask, INET6_ADDRSTRLEN);
+        for (size_t i = 0; i < sizeof(net_addr->sin6_addr.s6_addr); ++i) {
+          unsigned char cidrRaw = net_addr->sin6_addr.s6_addr[i];
+          while (cidrRaw) {
+            cidr += cidrRaw & 1;
+            cidrRaw >>= 1;
+          }
+        }
       }
       cidr_ = cidr;
       break;
