@@ -8,7 +8,13 @@ Mode::Mode(const std::string& id, const Json::Value& config)
   ipc_.subscribe(R"(["mode"])");
   ipc_.signal_event.connect(sigc::mem_fun(*this, &Mode::onEvent));
   // Launch worker
-  worker();
+  ipc_.setWorker([this] {
+    try {
+      ipc_.handleEvent();
+    } catch (const std::exception& e) {
+      spdlog::error("Mode: {}", e.what());
+    }
+  });
   dp.emit();
 }
 
@@ -31,16 +37,6 @@ void Mode::onEvent(const struct Ipc::ipc_response& res) {
   }
 }
 
-void Mode::worker() {
-  thread_ = [this] {
-    try {
-      ipc_.handleEvent();
-    } catch (const std::exception& e) {
-      spdlog::error("Mode: {}", e.what());
-    }
-  };
-}
-
 auto Mode::update() -> void {
   if (mode_.empty()) {
     event_box_.hide();
@@ -51,6 +47,8 @@ auto Mode::update() -> void {
     }
     event_box_.show();
   }
+  // Call parent update
+  ALabel::update();
 }
 
 }  // namespace waybar::modules::sway
